@@ -1,6 +1,6 @@
 package Test::Class::Moose;
 {
-  $Test::Class::Moose::VERSION = '0.10';
+  $Test::Class::Moose::VERSION = '0.11';
 }
 
 # ABSTRACT: Test::Class + Moose
@@ -333,6 +333,11 @@ END
 
 sub test_classes {
     my $self        = shift;
+
+    if ( my $classes = $self->test_configuration->test_classes ) {
+        return @$classes;
+    }
+
     my %metaclasses = Class::MOP::get_all_metaclasses();
     my @classes;
     foreach my $class ( keys %metaclasses ) {
@@ -435,7 +440,7 @@ Test::Class::Moose - Test::Class + Moose
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -465,7 +470,7 @@ version 0.10
 
 =head1 DESCRIPTION
 
-This is B<ALPHA> code. I encourage you to give it a shot if you want test
+This is B<BETA> code. I encourage you to give it a shot if you want test
 classes based on Moose, along with reporting. Feedback welcome as we try to
 improve it.
 
@@ -637,10 +642,18 @@ To override a test control method, just remember that this is OO:
 
 =head1 RUNNING THE TEST SUITE
 
- use Test::Class::Moose::Load 't/lib';
- Test::Class::Moose->new->runtests
+We I<strongly> recommend using L<Test::Class::Moose::Load> as the driver for
+your test suite. Simply point it at the directory or directories containing
+your test classes:
 
-Or:
+ use Test::Class::Moose::Load 't/lib';
+ Test::Class::Moose->new->runtests;
+
+By running C<Test::Class::Moose> with a single driver script like this, all
+classes are loaded once and this can be a significant performance boost. This
+does mean a global state will be shared, so keep this in mind.
+
+You can also pass arguments to C<Test::Class::Moose>'s contructor.
 
  my $test_suite = Test::Class::Moose->new({
      show_timing => 1,
@@ -681,6 +694,21 @@ Defaults to C<< Test::Builder->new >>. You can supply your own builder if you
 want, but it must conform to the L<Test::Builder> interface. We make no
 guarantees about which part of the interface it needs.
 
+=item * C<test_classes>
+
+Takes a class name or an array reference of class names. If it is present,
+only these test classes will be run. This is very useful if you wish to run an
+individual class as a test:
+
+    Test::Class::Moose->new(
+        test_classes => $ENV{TEST_CLASS}, # ignored if undef
+    )->runtests;
+
+You can also achieve this effect by writing a subclass and overriding the
+C<test_classes> method, but this makes it trivial to do this:
+
+    TEST_CLASS=TestsFor::Our::Company::Invoice prove -lv t/test_classes.t
+
 =item * C<include>
 
 Regex. If present, only test methods whose name matches C<include> will be
